@@ -72,6 +72,10 @@ class JetDjangoConfiguration(Configuration):
             'DATABASE_ONLY': settings.JET_DATABASE_ONLY,
             'DATABASE_EXCEPT': settings.JET_DATABASE_EXCEPT,
             'DATABASE_SCHEMA': settings.JET_DATABASE_SCHEMA,
+            'DATABASE_SSH_HOST': settings.JET_DATABASE_SSH_HOST,
+            'DATABASE_SSH_PORT': settings.JET_DATABASE_SSH_PORT,
+            'DATABASE_SSH_USER': settings.JET_DATABASE_SSH_USER,
+            'DATABASE_SSH_PRIVATE_KEY': settings.JET_DATABASE_SSH_PRIVATE_KEY,
             'COOKIE_SAMESITE': settings.JET_COOKIE_SAMESITE,
             'COOKIE_SECURE': settings.JET_COOKIE_SECURE,
             'COOKIE_DOMAIN': settings.JET_COOKIE_DOMAIN,
